import json
from optparse import OptionParser
import numpy as np
import matplotlib.pyplot as plt
from glob import glob

np.set_printoptions(precision=3, suppress=1)

fnames = glob('test.gamma-R0.seed*txt')
fnames.sort()


for ii, fname in enumerate(fnames):
    arrays = {}
    fig = plt.figure()
    ax = fig.add_subplot(111)
    with open(fname) as fd:
        data = [json.loads(line) for line in fd]
        keys = list(data[0].keys())
        for key in keys:
            arrays[key] = np.array([d[key] for d in data])

    xname = 'R0'
    yname = 'gamma'
    zname = 'err'
    X = arrays[xname]
    Y = arrays[yname]
    ax.set_xlabel(xname)
    ax.set_ylabel(yname)
    ax.set_title(zname)

    x = np.unique(X)
    y = np.unique(Y)
    nx = len(x)
    ny = len(y)
    assert nx * ny == len(X)

    X, Y = np.meshgrid(x, y)
    #print(Y)
    Z = arrays[zname].reshape(ny, nx)

    contour = ax.contourf(X, Y, Z.clip(0.0, 1.2), 64)
    ax.set_xscale('log')
    ax.set_yscale('log')
    ax.axis(xmax=1e8)
    plt.colorbar(contour)
    #ax.semilogx(arrays[xname], arrays[yname], 'o-')
    fig.savefig('output.seed{:02d}.png'.format(ii))
    #ax.set_xlabel(xname)
    #ax.set_ylabel(yname)

plt.show()
